

export interface Identity {
    identity?: string; 
}


export interface Empty {

}


export interface CompanyListRequest {
    page_no?: number;  //  页数 
    page_size?: number;  //  每页记录数 
    name?: string;  //  企业名称 
    status?: number;  //  认证状态: 1 已注册、2 已认证 
    relation_genre?: number;  //  关联关系类型: 1 成员企业、2 分销企业、3 供货企业 
    registered_start_at?: string;  //  注册时间-开始,格式:2006-01-02 15:04:05 
    registered_end_at?: string;  //  注册时间-结束格式:2006-01-02 15:04:05 
    with_statistics?: boolean;  //  是否需要查询统计信息 
}


export interface CompanyListReply {
    list?: CompanyItem[]; 
    count?: number; 
    statistics?: CompanyStatisticsData; 
}


export interface CompanyItem {
    id?: number; 
    identity?: string; 
    name?: string;  //  企业名称 
    unicode?: string;  //  信用代码 
    logo?: string;  //  企业Logo 
    profile?: string;  //  企业头像 
    genre?: number;  //  企业类型: 1 企业、2 资金方、3 物流企业 etc. 
    registered_at?: string;  //  注册时间 
    authorized_at?: string;  //  认证时间 
    status?: number;  //  认证状态: 1 已注册、2 已认证 
    relation_genre?: number;  //  关联关系类型: 1 成员企业、2 分销企业、3 供货企业 
    relation_status?: number;  //  关联关系状态: 1 正常（表示关系可用）、2 已停用（表示关系不可用） 
    contact_name?: string;  //  联系人 
    contact_phone?: string;  //  联系电话 
    contact_address?: string;  //  联系地址(补充地址) 
    province_identity?: string;  // 省级identity 
    city_identity?: string;  //  市级identity 
    district_identity?: string;  //  区级identity 
    account?: string;  //  登录账号 
    password?: string;  //  登录密码 
    password_confirmed?: string;  //  确认密码密码,仅注册/修改需要 
}


export interface CompanyStatisticsData {
    total?: number;  //  总的企业数 
    available?: number;  //  可用的企业数 
    disable?: number;  //  停用企业数 
}


export interface DeliveryAddressListRequest {
    page_no?: number;  //  页数 
    page_size?: number;  //  每页记录数 
    contact_name?: string; 
    contact_phone?: string; 
}


export interface DeliveryAddressListReply {
    list?: DeliveryAddressItem[]; 
    count?: number; 
}


export interface DeliveryAddressItem {
    identity?: string; 
    contact_name?: string;  //  联系人 
    contact_phone?: string;  //  联系电话 
    contact_address?: string;  //  联系地址(补充地址) 
    province_identity?: string;  // 省级identity 
    city_identity?: string;  //  市级identity 
    district_identity?: string;  //  区级identity 
    is_default?: boolean; 
    created_at?: string; 
}


export interface CollectionInformationItem {
    identity?: string; 
    company_identity?: string; 
    card_no?: string; 
    deposit_bank?: string; 
    payment_line?: string; 
    remark?: string; 
    created_at?: string; 
}


export interface RoleRequest {
    company_identity?: string[];  //  企业identity,如果不传具体的identity就查询所有的 
}


export interface RoleReply {
    kv?: { [key in string]: any};  //  key:company_identity 
}


export interface RoleList {
    list?: RoleItem[]; 
}


export interface RoleItem {
    id?: number; 
    identity?: string; 
    name?: string; 
    company_identity?: string; 
    created_at?: string; 
}


export interface StaffListRequest {
    page_no?: number;  //  页数 
    page_size?: number;  //  每页记录数 
    staff_name?: string; 
    company_name?: string; 
    status?: number; 
    registered_start_at?: string;  //  注册时间-开始,格式:2006-01-02 15:04:05 
    registered_end_at?: string;  //  注册时间-结束格式:2006-01-02 15:04:05 
    with_statistics?: boolean;  //  是否需要查询统计信息 
    staff_identity?: string; 
}


export interface StaffListReply {
    list?: StaffItem[]; 
    count?: number; 
    statistics?: StaffStatisticsData; 
}


export interface StaffItem {
    id?: number; 
    identity?: string; 
    name?: string; 
    account?: string; 
    profile?: string; 
    password?: string; 
    phone?: string; 
    email?: string; 
    status?: number; 
    creator_identity?: string; 
    created_at?: string; 
    staff_company?: StaffCompany[];  //  关联企业信息 
    password_confirmed?: string;  //  确认密码密码,仅注册/修改需要 
    sms_verify_code?: string;  //  创建时需要内容  短线验证码 
}


export interface StaffCompany {
    company_identity?: string; 
    role_identity?: string; 
    status?: number; 
    company_name?: string;  //  显示用 
    role_name?: string; 
    identity?: string; 
}


export interface StaffStatisticsData {
    total?: number;  //  总的 
    available?: number;  //  可用的 
    disable?: number;  //  停用 
}


export interface StaffCompanyRequest {
    list?: StaffCompanyItem[]; 
    staff_identity?: string;  // 管理端请求需要校验这个参数 
}


export interface StaffCompanyItem {
    company_identity?: string; 
    role_identity?: string; 
    status?: number; 
    identity?: string; 
}