

export interface Empty {

}


export interface FetchRequest {
    page_no?: number;  //  页数 
    page_size?: number;  //  每页记录数 
    params?: { [key in string]: any};  //  条件参数,key=val,eg key:category_id=?,vlaue=11  
}


export interface IdentRequest {
    id?: number;  //  唯一ID 
    identity?: string;  //  唯一码 
}


export interface StatusReply {
    status?: number;  //  状态码 
    identity?: string;  //  标识码 
    message?: string;  // 状态说明 
    timeseq?: number;  //  响应时间序列 
}


export interface CartGetRequest {
    cartIdentity?: string;  //  购物车唯一码，主要是用于未登录购物 
    passportIdentity?: string;  //  登录后的用户唯一码 
}


export interface CartGetReply {
    data?: CartItem[];  //  购物车中的商品数据列表 
}


export interface CartItem {
    id?: number;  //  ID 
    productId?: number;  //  商品ID 
    title?: string;  // 商品名称 
    coverImage?: string;  // 商品封面图片 
    salesPrice?: number;  // 商品销售价格 
    productArgs?: string;  //  商品属性 
    number?: number;  //  数量 
    unitPrice?: number;  //  实际单价 
    totalPrice?: number;  //  总价 
}


export interface CartAddRequest {
    cartIdentity?: string;  //  购物车唯一码，主要是用于未登录购物 
    passportIdentity?: string;  //  登录后的用户唯一码 
    productId?: number;  //  商品ID 
    productArgs?: string;  //  商品属性 
    number?: number;  //  数量 
}


export interface CartSetRequest {
    id?: number;  //  购物车ID 
    number?: number;  //  数量 
    unitPrice?: number;  //  单价 
}


export interface CartDelRequest {
    id?: number[];  //  购物车ID 
}


export interface Status {
    status?: number;  // 优惠卷状态 
}


export interface CouponListReply {
    data?: CouponItem[];  //  购物车中的商品数据列表 
}


export interface CouponItem {
    id?: number;  //  ID 
    identity?: string;  //  唯一码 
    title?: string;  // 标题 
    intro?: string;  // 描述 
    amount?: string;  // 金额 
    started?: string;  //  开始时间 
    expired?: string;  //  结束时间 
    status?: string;  //  状态 
}


export interface PlanItem {
    id?: number;  //  ID 
    identity?: number;  //  计划唯一标识 
    title?: string;  // 计划名称 
    descr?: string;  // 计划描述 
    passport_identity?: string;  //  用户唯一码 
}


export interface FetchReply {
    data?: PlanItem[];  //  采购计划列表 
}


export interface CancelPlanRequest {
    id?: number[]; 
}


export interface QuickCreateByCodeRequest {
    partner_id?: number;  //  合伙人ID 
    product_identity?: string;  //  商品唯一码 
    number?: number;  //  数量 
    phone?: string;  //  手机号 
    address?: string;  //  详情地址 
    contact?: string;  //  联系人 
    code?: string;  // 短信验证码 
}


export interface QuickCreateByTokenRequest {
    partner_id?: number;  //  合伙人ID 
    product_identity?: string;  //  商品唯一码 
    number?: number;  //  数量 
    args?: string;  //  相关参数 
}


export interface SubmitRequest {
    id?: string[];  //  购物车的ID数据，以逗号分开 
    partner_id?: number;  //  合伙人ID 
    address_id?: number;  //  地址ID 
}


export interface SummaryGetReply {
    summary?: OrderSummary;  //  订单概要详情 
    details?: OrderDetails[];  //  订单商品详情 
}


export interface OrderSummary {
    id?: number;  //  ID 
    order_no?: string;  //  订单唯一码 
    partner_id?: number;  //  合伙人ID 
    tradeNo?: string;  //  支付交易号 
    payType?: number;  //  支付类型 
    address?: string;  //  收货地址 
    total_price?: number;  //  总价 
    trans_price?: number;  //  交易金额 
    refund_price?: number;  //  退款金额 
    logistics_number?: string;  //  物流信息 
    logistics_fee?: number;  //  物流信息 
    coupon_amount?: number;  //  物流信息 
    remark?: string;  //  备注 
    status?: number;  //  订单状态 
    payTime?: string;  //  支付时间 
    created?: string;  //  创建时间 
    updated?: string;  //  最后创建时间 
    details?: OrderDetails[];  // 订单商品 
}


export interface OrderDetails {
    id?: number;  //  ID 
    product_id?: number;  //  商品ID 
    type?: number;  //  商品类型 
    title?: string;  // 商品名称 
    cover_image?: string;  // 商品封面图片 
    sales_price?: string;  // 商品销售价格 
    product_args?: string;  //  商品参数 
    number?: number;  //  数量  
    unitPrice?: number;  //  单价 
}


export interface SummaryListRequest {
    type?: string;  //  订单类型 
}


export interface SummaryListReply {
    summary?: OrderSummary[];  //  订单列表 
}


export interface ConfirmRequest {
    order_no?: number;  //  订单唯一码 
    address_id?: number;  //  订单唯一码 
    coupon_identity?: string;  //  优惠卷 
    remark?: string;  // 备注 
    logisticsFee?: number;  // 运费 
}


export interface ConfirmReply {
    total_price?: number;  //  总价 
}


export interface CancelRequest {
    order_no?: number;  //  订单唯一码 
    type?: string;  //  订单类型 
}