

export interface FetchRequest {
    page_no?: number;  //  页数 
    page_size?: number;  //  每页记录数 
    params?: { [key in string]: any};  //  条件参数,key=val,eg key:category_id=?,vlaue=11  
}


export interface IdentRequest {
    id?: number;  //  唯一ID 
    identity?: string;  //  唯一码 
}


export interface VersionRequest {
    version?: number;  //  时序版本号 
}


export interface SearchRequest {
    keyword?: string;  // 关键词 
}


export interface StatusReply {
    status?: number;  //  状态码 
    identity?: string;  //  标识码 
    message?: string;  // 状态说明 
    timeseq?: number;  //  响应时间序列 
}


export interface Empty {

}


export interface VerifyRequest {
    phone?: string;  // 手机号 
    code?: string;  //  验证码 
}


export interface ForgetResetRequest {
    identity?: string;  // 唯一码 
    password?: string;  //  密码 
}


export interface ForgetReply {
    identity?: string;  // 用户唯一码 
    data_bind?: string;  //  数据绑定的相关说明,PASS通过，NOPHONE没有绑定手机号，NOPWD没有设置密码，NOBIND没有手机号同时没有密码 
    token?: string;  // 用户凭证 
    extend?: { [key in string]: any};  // 扩展字段 
}


export interface BindRequest {
    action?: string;  // 操作动作 
    phone?: string;  //  手机号码 必填 
    code?: string;  //  验证码 
    password?: string;  //  密码 必填 
    nickname?: string;  //  昵称 
}


export interface GetDataReply {
    account?: string;  // 帐号 
    phone?: string;  // 手机号 
    nickname?: string;  // 昵称 
    avatar?: string;  // 头像 
    birthday?: string;  // 生日 
    sex?: number;  // 性别，1为男性，2为女性 
    province?: number;  // 省 
    city?: number;  // 市 
    area?: number;  // 区 
    sign?: string;  // 签名 
    approve?: number;  // 状态：-2,认证未通过，0为未认证，1为审核中，2为认证成功 
}


export interface SetDataRequest {
    nickname?: string;  // 昵称 
    avatar?: string;  // 头像 
    birthday?: string;  // 生日 
    sex?: number;  // 性别，1为男性，2为女性 
    province?: number;  // 省 
    city?: number;  // 市 
    area?: number;  // 区 
    sign?: string;  // 签名 
}


export interface SetPasswordRequest {
    old_password?: string;  //  旧密码 
    new_password?: string;  //  新密码 
}


export interface StatisticsRequest {
    field?: string[];  // 要获取的统计数据字段。 
}


export interface StatisticsReply {
    Data?: { [key in string]: any};  // 数据以Map格式输出 
}


export interface LoginByPwdRequest {
    account?: string;  //  账号 必填 
    password?: string;  //  密码 必填 
    device?: string;  //  设备 必填 
}


export interface LoginByCodeRequest {
    country?: string;  //  国家 
    phone?: string;  //  手机号码 
    code?: string;  //  验证码 
    device?: string;  //  设备 
}


export interface WeChatByCodeRequest {
    code?: string;  //  WeChat code 
    agency_id?: number;  //  代理ID 
    staff_id?: number;  //  工作人员ID 
}


export interface WeChatByPhoneReply {
    account?: string;  //  WeChat code 
}


export interface WeChatByCodeReply {
    session_key?: string;  //  WeChat session key 
    open_id?: string;  //  WeChat open id 
    identity?: string;  //  identity 
    account?: string;  //  account 
}


export interface WeChatByPhoneRequest {
    session_key?: string;  //  WeChat session key 
    open_id?: string;  //  open_id 
    data?: string;  //  data 
    iv?: string;  //  iv 
    identity?: string;  //  identiy 
}


export interface WeChatGetUserinfoReply {
    id?: number; 
    account?: string; 
    identity?: string; 
    nickname?: string; 
    avatar?: string; 
    rights?: string; 
    token?: string; 
}


export interface LoginByAppleIDRequest {
    apple_id?: string;  //  apple id 
    desc?: string;  //  描述 
    device?: string;  //  设备 
}


export interface LoginReply {
    id?: number; 
    identity?: string;  // 用户唯一码 
    data_bind?: string;  //  数据绑定的相关说明,PASS通过，NOPHONE没有绑定手机号，NOPWD没有设置密码，NOBIND没有手机号同时没有密码 
    token?: string;  // 用户凭证 
    extend?: { [key in string]: any};  // 扩展字段 
}


export interface RegisterRequest {
    origin?: string;  // 来源，归属 
    account?: string;  // 帐号 
    phone?: string;  // 手机号 
    password?: string;  // 密码 
    code?: string;  // 验证码 
    wechat_union_id?: string;  // 微信UnionID 
    wechat_open_id?: string;  // 微信OpenID 
    apple_id?: string;  // Apple ID 
    nickname?: string;  // 昵称 
    type?: string;  // 类型 
    device?: string;  // 设备 
    agency_id?: number;  //  代理ID 
    staff_id?: number;  //  工作人员ID 
}


export interface RegisterReply {
    id?: number; 
    identity?: string;  // 用户唯一码 
    data_bind?: string;  //  数据绑定的相关说明,PASS通过，NOPHONE没有绑定手机号，NOPWD没有设置密码，NOBIND没有手机号同时没有密码 
    token?: string;  // 用户Header所需Token 
    extend?: { [key in string]: any};  // 扩展字段 
}